@@ -5,7 +5,7 @@ from __future__ import print_function
     pre-req: Having a dataset following a specific template:
          --> all sources are mapped to one or more tables under the "Master Tables"'s group
     usage: this command will unmap column/table all tables under "Master Tables"
-        group and thendelete all sources from project
+        group and then delete all sources from project
     date: 02/12/2020
     author: clement
 """
@@ -21,26 +21,24 @@ DATASET_ID = 'DATASET'
 
 def delete_source():
     # login
-    username = raw_input("Username: ")
+    username = input("Username: ")
     password = getpass.getpass()
 
     api = Spyglass(WS_URL, username, password)
     print(
-            "\n------ connected to " + DATASET_ID + ' on ' + WS_URL + " ------\n")
+        "\n------ connected to " + DATASET_ID + ' on ' + WS_URL + " ------\n")
 
     # session
     try:
-        api.sync_cmd("session", positional_args=[DATASET_ID],
-                     keyword_args={'no_pool': None})
+        api.cmd("session", DATASET_ID, no_pool=None)
     except LoreException as e:
         print(e)
         sys.exit()
 
     # filter Master Tables group
     try:
-        resp_table = api.sync_cmd('table', positional_args=[],
-                                  keyword_args={
-                                      'filter': '\'{"table_group": "Master Tables"}\''})
+        resp_table = api.cmd('table',
+                             filter='\'{"table_group": "Master Tables"}\'')
     except LoreException as e:
         print(e)
         sys.exit()
@@ -53,16 +51,13 @@ def delete_source():
         len(master_tables)) + " table(s) from LoreIO: \n\n" +
                      "'" + ', '.join(
         master_tables) + "'" + " \n\n(" + WS_URL + ") ? [y/n]")
-    choice = raw_input().lower()
+    choice = input().lower()
     if choice not in ["y", "yes"]:
         sys.exit()
 
     # loop over master tables
     try:
-
-        resp = api.sync_cmd('table', positional_args=[],
-                            keyword_args={
-                                'filter': '\'{"name": "Event"}\''})
+        resp = api.cmd('table', filter='\'{"name": "Event"}\'')
     except LoreException as e:
         print(e)
 
@@ -70,17 +65,14 @@ def delete_source():
     for table in resp_table['data']:
         table_id = table['id']
         # re-define all columns to null map columns
-        resp = api.sync_cmd('dimension', positional_args=[],
-                            keyword_args={
-                                'filter': '\'{"table": "id"}\''})
+        resp = api.cmd('dimension', filter='\'{"table":"' + table_id + '"}\'')
         # loop over columns
         for col in resp['data']:
             col_id = col['id']
             col['calculation']['args'] = []
             col = json.dumps(col)
             try:
-                api.sync_cmd('dimension', positional_args=[col_id],
-                             keyword_args={'put': "'" + col + "'"})
+                api.cmd('dimension', col_id, put="'" + col + "'")
             except LoreException as e:
                 print(e)
 
@@ -96,18 +88,15 @@ def delete_source():
             continue
         table = json.dumps(table)
         try:
-            resp = api.sync_cmd('table',
-                                positional_args=[table_id],
-                                keyword_args={
-                                    'put': "'" + table + "'"})
+            resp = api.cmd('table',
+                           table_id,
+                           put="'" + table + "'")
         except LoreException as e:
             print(e)
 
     # delete all sources
     try:
-        resp = api.sync_cmd('table', positional_args=[],
-                            keyword_args={
-                                'filter': '\'{"table_group": "Source Tables"}\''})
+        resp = api.cmd('table', filter='\'{"table_group": "Source Tables"}\'')
     except LoreException as e:
         print(e)
 
@@ -118,7 +107,7 @@ def delete_source():
     sys.stdout.write("do you want to delete " + str(
         len(source_tables)) + " sources tables:\n " +
                      ', '.join(source_tables) + "? [y/n]  \n")
-    choice = raw_input().lower()
+    choice = input().lower()
     if choice not in ["y", "yes"]:
         print('\nDone')
         sys.exit()
@@ -127,9 +116,7 @@ def delete_source():
     for table in resp['data']:
         table_id = table['id']
         try:
-            api.sync_cmd('table',
-                         positional_args=[table_id],
-                         keyword_args={'delete': None})
+            api.cmd('table', table_id, delete=None)
         except LoreException as e:
             print(e)
 
