@@ -6,15 +6,15 @@ url = 'wss://ui.getlore.io/storyteller'
 user = 'maurin'
 pwd = 'MA123$%'
 
-spyglass = Spyglass(url, user, pwd, dataset_id='payu_v3')
+spyglass = Spyglass(url, user, pwd, dataset_id='tvfplay')
 
-tables = ['@transactions_payubiz']
+tables = ['@TABLE_NAME']
 
 for table in tables:
-    results = spyglass.sync_cmd('aql', [
+    results = spyglass.cmd('aql',
         ''' 'select count(*) from "{table}" where ingestion_date = \\'{date}\\'' '''
-                                .format(table=table,
+                           .format(table=table,
                                         date=time.strftime("%Y-%m-%d")),
-        '--json'])
+        json=None)
     assert results['data']['series'][0]['data'][0][
                'count'] > 0, "check failed for table : {} ".format(table)
